.. -*- coding: utf-8 -*-

Citing
======

To cite NetworkX please use the following publication:

Aric A. Hagberg, Daniel A. Schult and Pieter J. Swart, 
`"Exploring network structure, dynamics, and function using NetworkX"
<http://conference.scipy.org/proceedings/SciPy2008/paper_2/>`_,
in
`Proceedings of the 7th Python in Science Conference (SciPy2008)
<http://conference.scipy.org/proceedings/SciPy2008/index.html>`_, Gäel
Varoquaux, Travis Vaught, and Jarrod Millman (Eds), (Pasadena, CA
USA), pp. 11--15, Aug 2008

.. only:: html

   `PDF <http://math.lanl.gov/~hagberg/Papers/hagberg-2008-exploring.pdf>`_
   `BibTeX <http://math.lanl.gov/~hagberg/Publications/hagberg-2008-exploring.shtml>`_
